==> test-utils-0.1.0.tgz: package/index.js <==
const _ = require('lodash');
const randomstring = require('randomstring');
const {User} = require('@codefresh-io/authenticated-entity');
const { mongoClient } = require('@codefresh-io/service-base');

const mongoUri = process.env.MONGO_URI || 'mongodb://codefresh.dev:27017';

function initTestUtils(dropTestDatabase = true) {
  const dbName = `unit_tests_${randomstring.generate(5)}`;
  let mock_user = null;
  const mockRequests = [];

  jest.mock('request-promise', () => {
    const rp = require.requireActual('request-promise');
    return opts => {
      const mockReq = mockRequests.find(req => _.isMatch(opts, req.opts));
      const resp = _.get(mockReq, 'resp');
      return mockReq ? Promise.resolve(_.isFunction(resp) ? resp(opts) : resp) : rp(opts);
    };
  });

  jest.mock('@codefresh-io/service-base', () => {
    const serviceBase = require.requireActual('@codefresh-io/service-base');
    serviceBase.getAuthenticatedEntity = () => mock_user;

    const originalServiceRequest = serviceBase.request;
    serviceBase.request = opts => {
      const mockReq = mockRequests.find(req => _.isMatch(opts, req.opts));
      const resp = _.get(mockReq, 'resp');
      return mockReq ? Promise.resolve(_.isFunction(resp) ? resp(opts) : resp) : originalServiceRequest(opts);
    }

    return serviceBase;
  });

  beforeAll(() => {
    return mongoClient.init({mongo: {uri: `${mongoUri}/${dbName}`}})
  });

  afterEach(() => {
    _.pullAllBy(mockRequests, [{preserve: false}], 'preserve')

    if (dropTestDatabase) {
      return mongoClient.db.collections()
        .then(collections => Promise.all(
          collections
            .filter(({collectionName}) => !collectionName.startsWith('system.'))
            .map(collection => collection.remove({}))
        ));
    }
  });

  afterAll(() => {
    if (dropTestDatabase) {
      return mongoClient.db.dropDatabase()
        .then(() => mongoClient.stop());
    }
  });

  return {
    setAuthenticatedUser: (data) => { mock_user = new User(data) },
    mockRequest: (opts, resp, preserveBetweenTests) => mockRequests.push({opts, resp, preserve: !!preserveBetweenTests})
  }
}

const generateObjectId = () => new mongoClient.ObjectId().toString()

function errorTest(description, testFunc, ...words) {
  it(description, function() {
    const result = testFunc();
    return Promise.all(words.map(word => expect(result).rejects.toHaveProperty('message', expect.stringContaining(word))));
  });
}

module.exports = {
  initTestUtils,
  generateObjectId,
  errorTest
};

==> test-utils-0.1.1.tgz: package/index.js <==
const _ = require('lodash');
const randomstring = require('randomstring');
const {User} = require('@codefresh-io/authenticated-entity');
const { mongoClient } = require('@codefresh-io/service-base');

const mongoUri = process.env.MONGO_URI || 'mongodb://codefresh.dev:27017';

function initTestUtils(dropTestDatabase = true) {
  const dbName = `unit_tests_${randomstring.generate(5)}`;
  let mock_user = null;
  const mockRequests = [];

  jest.mock('request-promise', () => {
    const rp = require.requireActual('request-promise');
    return opts => {
      const mockReq = mockRequests.find(req => _.isMatch(opts, req.opts));
      const resp = _.get(mockReq, 'resp');
      return mockReq ? Promise.resolve().then(() => _.isFunction(resp) ? resp(opts) : resp) : rp(opts);
    };
  });

  jest.mock('@codefresh-io/service-base', () => {
    const serviceBase = require.requireActual('@codefresh-io/service-base');
    serviceBase.getAuthenticatedEntity = () => mock_user;

    const originalServiceRequest = serviceBase.request;
    serviceBase.request = opts => {
      const mockReq = mockRequests.find(req => _.isMatch(opts, req.opts));
      const resp = _.get(mockReq, 'resp');
      return mockReq ? Promise.resolve().then(() => _.isFunction(resp) ? resp(opts) : resp) : originalServiceRequest(opts);
    }

    return serviceBase;
  });

  beforeAll(() => {
    return mongoClient.init({mongo: {uri: `${mongoUri}/${dbName}`}})
  });

  afterEach(() => {
    _.pullAllBy(mockRequests, [{preserve: false}], 'preserve')

    if (dropTestDatabase) {
      return mongoClient.db.collections()
        .then(collections => Promise.all(
          collections
            .filter(({collectionName}) => !collectionName.startsWith('system.'))
            .map(collection => collection.remove({}))
        ));
    }
  });

  afterAll(() => {
    if (dropTestDatabase) {
      return mongoClient.db.dropDatabase()
        .then(() => mongoClient.stop());
    }
  });

  return {
    setAuthenticatedUser: (data) => { mock_user = new User(data) },
    mockRequest: (opts, resp, preserveBetweenTests) => mockRequests.push({opts, resp, preserve: !!preserveBetweenTests})
  }
}

const generateObjectId = () => new mongoClient.ObjectId().toString()

function errorTest(description, testFunc, ...words) {
  it(description, function() {
    const result = testFunc();
    return Promise.all(words.map(word => expect(result).rejects.toHaveProperty('message', expect.stringContaining(word))));
  });
}

module.exports = {
  initTestUtils,
  generateObjectId,
  errorTest
};
